@@ -27,32 +27,35 @@ log = logging.getLogger(__name__)
 
 def get_dimensions_codes_order(dataset_json):
     """Try to get dimensions codes order from `dataset.json` properties, with 2 fallbacks."""
-    return dataset_json.get("dimensions_codes_order") or \
-        sorted(dataset_json.get("dimensions_labels", {}).keys()) or \
-        sorted(dataset_json.get("dimensions_values_labels", {}).keys())
+    return (
+        dataset_json.get("dimensions_codes_order")
+        or sorted(dataset_json.get("dimensions_labels", {}).keys())
+        or sorted(dataset_json.get("dimensions_values_labels", {}).keys())
+    )
 
 
 def get_dimensions_values_labels(dataset_json):
     """Get dimensions values labels from `dataset.json` properties
-        Normalising tuple list values as dict (default) or OrderedDict
-        (form tuple list values)
+    Normalising tuple list values as dict (default) or OrderedDict
+    (form tuple list values)
 
-        # No dimensions_values_labels declared
-        >>> get_dimensions_values_labels({})
-        {}
+    # No dimensions_values_labels declared
+    >>> get_dimensions_values_labels({})
+    {}
 
-        # Unsorted dimension values
-        >>> get_dimensions_values_labels({'dimensions_values_labels':{'freq':{'A':'Annual','Q':'Quarterly'}}})['freq'].get('A')
-        'Annual'
+    # Unsorted dimension values
+    >>> get_dimensions_values_labels({'dimensions_values_labels':{'freq':{'A':'Annual','Q':'Quarterly'}}})['freq'].get('A')
+    'Annual'
 
-        # Sorted dimension values
-        >>> get_dimensions_values_labels({'dimensions_values_labels':{'geo':[['FR','France'],['SE','Sweden'],['RE','Rest of Europe']]}})['geo'].items()
-        odict_items([('FR', 'France'), ('SE', 'Sweden'), ('RE', 'Rest of Europe')])
+    # Sorted dimension values
+    >>> get_dimensions_values_labels({'dimensions_values_labels':{'geo':[['FR','France'],['SE','Sweden'],['RE','Rest of Europe']]}})['geo'].items()
+    odict_items([('FR', 'France'), ('SE', 'Sweden'), ('RE', 'Rest of Europe')])
 
-        # Missing level of dict
-        >>> get_dimensions_values_labels({'dimensions_values_labels':{'A':'Annual','Q':'Quarterly'}})
-        {}
+    # Missing level of dict
+    >>> get_dimensions_values_labels({'dimensions_values_labels':{'A':'Annual','Q':'Quarterly'}})
+    {}
     """
+
     def iter_dimensions_values_labels():
         for k, v in dim_val_labels.items():
             if isinstance(v, dict):
