@@ -216,17 +216,17 @@ def detect_frequency(period1, period2):
     >>> detect_frequency('2014-01-01', '2014-02-01')  # doctest: +ELLIPSIS
     (<Frequency.MONTHLY: 'monthly'>, ...)
     >>> detect_frequency('2014-01-15', '2014-02-15')  # doctest: +ELLIPSIS
-    (<Frequency.MONTHLY: 'monthly'>, None)
+    (<Frequency.MONTHLY: 'monthly'>, ...)
     >>> detect_frequency('2014-01-01', '2014-01-31')  # doctest: +ELLIPSIS
-    (<Frequency.DAILY: 'daily'>, None)
+    (<Frequency.DAILY: 'daily'>, ...)
     >>> detect_frequency('2014-01-06', '2014-01-13')  # doctest: +ELLIPSIS
     (<Frequency.WEEKLY: 'weekly'>, ...)
     >>> detect_frequency('2014-01-07', '2014-01-14')  # doctest: +ELLIPSIS
-    (<Frequency.WEEKLY: 'weekly'>, None)
+    (<Frequency.WEEKLY: 'weekly'>, ...)
     >>> detect_frequency('2014-01-06', '2014-01-14')  # doctest: +ELLIPSIS
-    (<Frequency.DAILY: 'daily'>, None)
+    (<Frequency.DAILY: 'daily'>, ...)
     >>> detect_frequency('2014-01-03', '2014-01-11')  # doctest: +ELLIPSIS
-    (<Frequency.DAILY: 'daily'>, None)
+    (<Frequency.DAILY: 'daily'>, ...)
 
     # Invalid or different period formats:
     >>> detect_frequency('2014', '2015-02')
@@ -239,16 +239,14 @@ def detect_frequency(period1, period2):
     (None, None)
     """
 
-    def make_normalize_period(frequency: Frequency, date_1: date, date_2: date):
-        def normalize_period(period):
+    def make_normalize_period(frequency: Frequency):
+        def normalize_period(period: str):
             period_date = datetime.fromisoformat(period)
+            if not is_start_day(period_date, frequency):
+                return period
             return start_day_to_period(period_date, frequency)
 
-        return (
-            normalize_period
-            if is_start_day(date_1, frequency) and is_start_day(date_2, frequency)
-            else None
-        )
+        return normalize_period
 
     period1_format, normalize_period = detect_period_format(period1)
     period2_format, _ = detect_period_format(period2)
@@ -271,32 +269,32 @@ def detect_frequency(period1, period2):
         elif date_diff.days == 7:
             return (
                 Frequency.WEEKLY,
-                make_normalize_period(Frequency.WEEKLY, date_1, date_2),
+                make_normalize_period(Frequency.WEEKLY),
             )
         elif date_diff.months == 1:
             return (
                 Frequency.MONTHLY,
-                make_normalize_period(Frequency.MONTHLY, date_1, date_2),
+                make_normalize_period(Frequency.MONTHLY),
             )
         elif date_diff.months == 2:
             return (
                 Frequency.BI_MONTHLY,
-                make_normalize_period(Frequency.BI_MONTHLY, date_1, date_2),
+                make_normalize_period(Frequency.BI_MONTHLY),
             )
         elif date_diff.months == 3:
             return (
                 Frequency.QUARTERLY,
-                make_normalize_period(Frequency.QUARTERLY, date_1, date_2),
+                make_normalize_period(Frequency.QUARTERLY),
             )
         elif date_diff.months == 6:
             return (
                 Frequency.BI_ANNUAL,
-                make_normalize_period(Frequency.BI_ANNUAL, date_1, date_2),
+                make_normalize_period(Frequency.BI_ANNUAL),
             )
         elif date_diff.years == 1:
             return (
                 Frequency.ANNUAL,
-                make_normalize_period(Frequency.ANNUAL, date_1, date_2),
+                make_normalize_period(Frequency.ANNUAL),
             )
         else:
             # No specific interval detected, keep daily.
