@@ -27,8 +27,8 @@ script_dir = Path(__file__).resolve().parent
 
 def test_crash():
     """Fail if validation script crash"""
-    fixture_dir = script_dir / 'fixtures' / 'provider5-json-data'
+    fixture_dir = script_dir / "fixtures" / "provider5-json-data"
     assert fixture_dir.exists()
 
-    sys.argv = ['validate_storage.py', str(fixture_dir)]
+    sys.argv = ["validate_storage.py", str(fixture_dir)]
     main()
